==> haskell-x509-system-1.6.6-90-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-system
version: 1.6.6
id: x509-system-1.6.6-9lR8tGFP4ZGJK7ZXYxmfVf
key: x509-system-1.6.6-9lR8tGFP4ZGJK7ZXYxmfVf
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling
category: Data
abi: 0a0a7224baa7d945599d03044b145051
exposed: True
exposed-modules:
    System.X509 System.X509.MacOS System.X509.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-system-1.6.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-system-1.6.6
hs-libraries: HSx509-system-1.6.6-9lR8tGFP4ZGJK7ZXYxmfVf
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    pem-0.2.4-99TOG2Rr4w4I5rsziTr4zP process-1.6.5.0
    x509-1.7.5-D34VBrGW3i7B6Eu45oEieF
    x509-store-1.6.7-3NApxTvogOMEihOVBqSlKH
haddock-interfaces: /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html: /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-system-1.6.6-91-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-system
version: 1.6.6
id: x509-system-1.6.6-2xvk0dHZCzXBxqJdF4HPw1
key: x509-system-1.6.6-2xvk0dHZCzXBxqJdF4HPw1
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling
category: Data
abi: fa6c779f8aeb169029da4c38aa1bbc5b
exposed: True
exposed-modules:
    System.X509 System.X509.MacOS System.X509.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-system-1.6.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-system-1.6.6
hs-libraries: HSx509-system-1.6.6-2xvk0dHZCzXBxqJdF4HPw1
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    pem-0.2.4-8CozJBHFqVTAJaxjlrM1Nk process-1.6.5.0
    x509-1.7.5-FYq9L5u5vSMBmP8UcLyKw3
    x509-store-1.6.7-4jyrMh4pgehI9uDPDRSS6v
haddock-interfaces: /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html: /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
